Constrained types: PositiveInt, NonEmptyString, EmailStr, SecretStr, HttpUrl, etc.
Modules
- network
- Network types: validated URLs, IP addresses.
- numeric
- Constrained numeric types.
- secret
- Secret types with redacted Debug/Display output.
- string
- Constrained string types.
Structs
- Email
Str - A validated email string.
- Finite
Float - A finite float (no NaN or infinity).
- HttpUrl
- A validated HTTP/HTTPS URL.
- Negative
Int - A negative integer (value < 0).
- NonEmpty
String - A non-empty string (length >= 1).
- NonNegative
Int - A non-negative integer (value >= 0).
- NonPositive
Int - A non-positive integer (value <= 0).
- Positive
Int - A positive integer (value > 0).
- Secret
- A generic secret wrapper for any type.
- Secret
Bytes - A secret bytes value that is redacted in Debug and Display output.
- Secret
Str - A secret string value that is redacted in Debug and Display output.